{% raw %}

/* Style file for the `plot_viewer` template. */


/* Text */
* {
    font-family: 'Times New Roman', Times, serif;
}

html, body {
    padding: 0.0;
    margin: 0.0;
}

body {
    font-size: 10pt;
}

h1 {
    margin-top: 0.0;
}

/* Navigation */

#navigation {
    background-color: #DDDDDD;
    position: sticky;
    top: 0;
    width: 100%;
    z-index: 100;
}

.nav {
    list-style-type: none;
    list-style: none;
    margin: 0;
    padding: 0;
}

.nav li {
    display: inline-block;
    margin: 0.25em;
    margin-right: 0;
    padding: 0;
}

.nav li a {
    text-decoration: none;
    display: block;
    padding: 0.5em;
    color: black;
    background-color: #EEE;
    margin: 0;
    font-size: 9pt;
    border: 1px solid grey;
    border-radius: 2px;
    box-shadow: 1px 1px 5px #BBBBBB;
}

.nav li a:hover {
    background-color: white;
}

/* Sections and plots */

.section {
    padding: 1em;
    margin: 0;
}

.plot-container {
    padding: 0;
    margin: 0.0;
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
}

.plot {
    width: 25em;

    padding: 1em;
    margin-bottom: 1em;
    margin-right: 1em;

    border: 1px solid grey;
    border-radius: 2px;
    box-shadow: 1px 1px 5px #BBBBBB;
}

.plot img {
    width: 100%;
}

.plot p {
    padding-bottom: 0;
    margin-bottom: 0;
}

.plot h3 {
    margin-top: 0.5em;
    margin-bottom: 0.0em;
}

/* Runs */

.run {
    width: 25em;

    padding: 1em;
    margin-bottom: 1em;
    margin-right: 1em;

    border: 1px solid grey;
    border-radius: 2px;
    box-shadow: 1px 1px 5px #BBBBBB;
    background-color: #EEE;
}

.run h3, h4 {
    margin-top: 0.0;
    margin-bottom: 1em;
}

.run ul {
    margin-left: 0.0;
    margin-top: 0.0;
}

.run p {
    margin-top: 0.0;
}

.run table {
    margin-top: 1em;
    margin-bottom: 1em;
}

/* Tables - only inside borders */

table {
    border-collapse: collapse;
    width: 100%;
    text-align: center;
}

table th {
    border: 1px solid grey;
    border-top: 0;
}


table tr th:first-child {
    border-left: 0;
}

table tr th:last-child {
    border-right: 0;
}

table td {
    border-right: 1px solid grey;
}

table tr td:last-child {
    border-right: 0;
}

/* Footer */

#footer {
    background-color: #DDDDDD;
    margin: 0;
    padding: 0;
    bottom: 0;
}

#footer p {
    padding: 0.5em;
    margin: 0;
}

{% endraw %}
